# IESopt: Integrated Energy System Optimization

[![License](https://img.shields.io/github/license/ait-energy/IESopt.jl)](LICENSE)
[![Docs](https://img.shields.io/badge/docs-stable-blue.svg)](https://ait-energy.github.io/iesopt-py/)

**IESopt** (_Integrated Energy System Optimization_) is a modeling and optimization framework for integrated energy
systems.

> Note: We are currently moving from our internal version control to GitHub. Missing contents will be added during the
> upcoming days ...

> ATTENTION: Code is currently not functional, since dependencies and internal imports are being cleaned up.

It is developed and maintained at the **Center for Energy** at
[AIT Austrian Institute of Technology GmbH](https://www.ait.ac.at/). The framework is designed to support the
optimization of energy systems that are characterized by a high degree of integration between different energy carriers
and sectors. It focuses on offering a modular and adaptable tool for modelers, that does not compromise on performance,
while still being user-friendly. This is enabled by reducing energy system assets to abstract building blocks, that are
supported by specialized implementation, and can be combined into complex systems without the need of a detailed
understanding of mathematical modeling or proficiency in any coding-language.

<!--
## Development

Run the following to locally check the code:

```bash
ruff check src/ tests/ docs/conf.py
black src/ tests/ docs/conf.py
codespell src/ tests/
```
-->
